# IdenDSS

This is a software for identifying taxon-specific signature sequence from a DNA database. Pleas refer to manual in [docs](docs) directory (only chinese for now).

Please refer to [https://github.com/Hua-CM/IdenDSS](https://github.com/Hua-CM/IdenDSS)

# Reference

- Hua, Z., Tian, D., Jiang, C., Song, S., Chen, Z., Zhao, Y., Jin, Y., Huang, L., Zhang, Z. and Yuan, Y. (2022), Towards comprehensive integration and curation of chloroplast genomes. Plant Biotechnol J. https://doi.org/10.1111/pbi.13923
- Hua, Z., Jiang, C., Song, S., Tian, D., Chen, Z., Jin, Y., Zhao, Y., Zhou, J., Zhang, Z., Huang, L., & Yuan, Y. (2022). Accurate identification of taxon-specific molecular markers in plants based on DNA signature sequence. *Molecular Ecology Resources*, 00, 1– 12. https://doi.org/10.1111/1755-0998.13697
